@@ -21,6 +21,10 @@ class IgProModelTest(unittest.TestCase):
         IG_INSIGHT = json.loads(f.read().decode("utf-8"))
     with open(BASE_PATH + "ig_story.json", "rb") as f:
         IG_STORY = json.loads(f.read().decode("utf-8"))
+    with open(BASE_PATH + "ig_container.json", "rb") as f:
+        IG_CONTAINER = json.loads(f.read().decode("utf-8"))
+    with open(BASE_PATH + "ig_publish_limit.json", "rb") as f:
+        IG_PUBLISH_LIMIT = json.loads(f.read().decode("utf-8"))
 
     def testUser(self):
         m = models.IgProUser.new_from_json_dict(self.IG_USER)
@@ -65,3 +69,15 @@ class IgProModelTest(unittest.TestCase):
 
         self.assertEqual(m.id, "17908009870517752")
         self.assertEqual(m.owner.id, "17841406338772941")
+
+    def testContainer(self):
+        m = models.IgProContainer.new_from_json_dict(self.IG_CONTAINER)
+
+        self.assertEqual(m.id, "17889615691921648")
+        self.assertEqual(m.status_code, "FINISHED")
+
+    def testPublishLimit(self):
+        m = models.IgProPublishLimit.new_from_json_dict(self.IG_PUBLISH_LIMIT)
+
+        self.assertEqual(m.quota_usage, 2)
+        self.assertEqual(m.config.quota_total, 25)
