@@ -7,8 +7,8 @@ from pyfacebook.utils.param_validation import enf_comma_separated
 class ParamValidationTest(unittest.TestCase):
     def testEnfCommaSeparated(self):
         self.assertEqual(enf_comma_separated("fields", "f1"), "f1")
-        self.assertEqual(enf_comma_separated("fields", "f1,f1,f2"), "f1,f2")
         self.assertEqual(enf_comma_separated("fields", ["f1", "f2"]), "f1,f2")
+        self.assertEqual(enf_comma_separated("fields", ["f1", "f2", "f2"]), "f1,f2")
         self.assertEqual(enf_comma_separated("fields", ("f1", "f2")), "f1,f2")
         self.assertTrue(enf_comma_separated("fields", {"f1", "f2"}))
 
